@@ -10,9 +10,28 @@ use XML::LibXML;
 use XML::Simple;
 use Data::Dumper;
 
-our @EXPORT     = qw/get_auth_id refs is_success get_data query_abstract/;
+# Main packages
+use API::ISPManager::ip;
+use API::ISPManager::user;
+use API::ISPManager::domain;
+
+# Addition packages
+use API::ISPManager::backup;
+use API::ISPManager::db;
+use API::ISPManager::preset;
+use API::ISPManager::stat;
+use API::ISPManager::services;
+use API::ISPManager::ftp;
+
+# VDSManager
+use API::ISPManager::vds;
+use API::ISPManager::diskpreset;
+use API::ISPManager::vdspreset;
+
+
+our @EXPORT     = qw/get_auth_id refs is_success get_data query_abstract is_ok get_error/;
 our @EXPORT_OK  = qw//;
-our $VERSION    = 0.02;
+our $VERSION    = 0.04;
 our $DEBUG      = '';
 
 =head1 NAME
@@ -86,18 +105,24 @@ API::ISPManager - interface to the ISPManager Hosting Panel API ( http://ispsyst
 
 =cut
 
-# Main packages
-use API::ISPManager::ip;
-use API::ISPManager::user;
-use API::ISPManager::domain;
+# Last raw answer from server 
+our $last_answer = ''; 
 
-# Addition packages
-use API::ISPManager::backup;
-use API::ISPManager::db;
-use API::ISPManager::preset;
-use API::ISPManager::stat;
-use API::ISPManager::services;
+# Public!
+sub is_ok {
+    my $answer = shift;
 
+    return '' unless $answer && ref $answer eq 'HASH' && $answer->{success};
+}
+
+
+sub get_error {
+    my $answer = shift;
+
+    return '' if is_ok($answer); # ok == no error
+
+    return Dumper( $answer->{error} );
+}
 
 # Get data from @_
 sub get_params {
@@ -319,7 +344,7 @@ sub refs {
     return ref $ref;
 }
 
-# Check server answer result
+# INTERNAL!!! Check server answer result
 # STATIC(data_block)
 sub is_success {
     my $data_block = shift;
